@@ -1,5 +1,3 @@
-#!/usr/bin/env python3
-
 """
 .. codeauthor:: Tsuyoshi Hombashi <tsuyoshi.hombashi@gmail.com>
 """
@@ -8,7 +6,7 @@ import logging
 from argparse import ArgumentParser, Namespace, RawDescriptionHelpFormatter
 from logging import Logger
 from textwrap import dedent
-from typing import AbstractSet
+from typing import AbstractSet, Optional
 
 from .__version__ import __version__
 from ._const import BUILD_CACHE_DIRS, IGNORE_DIRS, Category, LogLevel
@@ -21,7 +19,7 @@ def parse_option() -> Namespace:
         formatter_class=RawDescriptionHelpFormatter,
         description=dedent(
             """\
-            Remove cache files and temporary files that related to Python.
+            Remove cache files and temporary files that are related to Python.
 
             Skip directories from recursive search: {}
             """.format(
@@ -45,7 +43,10 @@ def parse_option() -> Namespace:
         dest="listing",
         action="store_true",
         default=False,
-        help="print target directories/files. does not actually remove.",
+        help="""
+        print target directories/files.
+        this does not actually remove directories/files.
+        """,
     )
     parser.add_argument(
         "--follow-symlinks", action="store_true", default=False, help="follow symlinks."
@@ -58,18 +59,21 @@ def parse_option() -> Namespace:
         "--all",
         action="store_true",
         default=False,
-        help="remove all of the caches and teporary files.",
+        help="remove all of the caches and temporary files.",
     )
     group_rm.add_argument(
         "--include-builds",
         action="store_true",
         default=False,
-        help="remove files/directories that related build: {}, docs/_build".format(
+        help="remove files/directories that are related to build: {}, docs/_build".format(
             ", ".join(BUILD_CACHE_DIRS)
         ),
     )
     group_rm.add_argument(
-        "--include-envs", action="store_true", default=False, help="remove virtual environments."
+        "--include-envs",
+        action="store_true",
+        default=False,
+        help="remove virtual environment caches.",
     )
     group_rm.add_argument(
         "--include-metadata", action="store_true", default=False, help="remove metadata."
@@ -85,13 +89,15 @@ def parse_option() -> Namespace:
         metavar="PATTERN",
         help=dedent(
             """\
-            a regular expression that matches files and
-            directories that should be excluded on recursive searches.
+            a regular expression for files and directories to be excluded from the removes.
             """
         ),
     )
     group_rm.add_argument(
-        "--exclude-envs", action="store_true", default=False, help="exclude virtual environments."
+        "--exclude-envs",
+        action="store_true",
+        default=False,
+        help="exclude virtual environments from deletion.",
     )
 
     interactive_dest = "interactive"
@@ -102,7 +108,7 @@ def parse_option() -> Namespace:
         dest=interactive_dest,
         action="store_true",
         default=False,
-        help="prompt before remove.",
+        help="prompt on each file/directory delete.",
     )
     group_interactive.add_argument(
         "-f",
@@ -110,7 +116,7 @@ def parse_option() -> Namespace:
         dest=interactive_dest,
         action="store_false",
         default=False,
-        help="no prompt before remove.",
+        help="delete file/directory without prompt.",
     )
 
     loglevel_dest = "log_level"
@@ -122,7 +128,7 @@ def parse_option() -> Namespace:
         action="store_const",
         const=logging.INFO,
         default=LogLevel.DEFAULT,
-        help="shows verbose output.",
+        help="shows the verbose output.",
     )
     group_logging.add_argument(
         "--debug",
@@ -166,7 +172,7 @@ def extract_log_level(log_level: int, dry_run: bool) -> int:
     return log_level
 
 
-def extract_categories(options) -> AbstractSet[str]:
+def extract_categories(options: Namespace) -> AbstractSet[str]:
     category_set = {Category.CACHE}
 
     if options.all:
@@ -187,6 +193,19 @@ def extract_categories(options) -> AbstractSet[str]:
     return category_set
 
 
+def extract_exclude_pattern(options: Namespace) -> Optional[str]:
+    virtual_env_pattern = r"\.venv|\.tox|\.nox"
+    exclude_pattern = options.exclude
+
+    if options.exclude_envs:
+        if options.exclude:
+            exclude_pattern = f"{options.exclude}|{virtual_env_pattern}"
+        else:
+            exclude_pattern = virtual_env_pattern
+
+    return exclude_pattern
+
+
 def main():
     options = parse_option()
     logger = get_logger(extract_log_level(options.log_level, options.dry_run))
@@ -199,7 +218,7 @@ def main():
     finder = Finder(
         logger,
         manipulator=manipulator,
-        exclude_pattern=options.exclude,
+        exclude_pattern=extract_exclude_pattern(options),
         include_categories=extract_categories(options),
     )
     target_dirs = set(options.target_dirs)
